@@ -38,7 +38,6 @@ from .qtlib import ColorSelecter
 from .app import white_palette, app
 from .. import param
 from ..pylib import print_error, debug, advanced_split, OrderedDict
-from ..geolib.constantes import NOM, FORMULE, TEXTE, RIEN
 from ..geolib.routines import nice_display
 
 class ProprietesAffichage(QWidget):
@@ -83,10 +82,10 @@ class ProprietesAffichage(QWidget):
                 mode = objets[0].mode_affichage
                 legende = QHBoxLayout()
                 self.radios = OrderedDict((
-                        (NOM, QRadioButton("Nom")),
-                        (TEXTE, QRadioButton(u"Texte")),
-                        (FORMULE, QRadioButton(u"Formule")),
-                        (RIEN, QRadioButton(u"Aucun")),
+                        ('nom', QRadioButton("Nom")),
+                        ('texte', QRadioButton(u"Texte")),
+                        ('formule', QRadioButton(u"Formule")),
+                        ('rien', QRadioButton(u"Aucun")),
                               ))
                 if all(objet.mode_affichage == mode for objet in objets):
                     self.radios[mode].setChecked(True)
@@ -165,13 +164,28 @@ class ProprietesAffichage(QWidget):
             if self.add_combo_box(hb, 'codage', 'Codage : ', codages_possibles):
                 encadre2.addLayout(hb)
 
-        # --------------------------------------------------------
-        # Styles s'appliquant aux textes seulement (fond et cadre)
-        # --------------------------------------------------------
+        # ------------------------------------------------------------------
+        # Styles s'appliquant aux textes seulement (alignement, fond, cadre)
+        # ------------------------------------------------------------------
 
         encadre3 = QVBoxLayout()
+        encadre5 = QVBoxLayout()
         if tous_de_meme_categorie and categorie == 'textes':
 
+            # ALIGNEMENT
+            # ==========
+
+            ha_values = ['left', 'center', 'right']
+            va_values = ['top', 'center', 'baseline', 'bottom']
+
+            hb = QHBoxLayout()
+            if self.add_combo_box(hb, 'alignement_horizontal', 'Alignement horizontal : ', ha_values):
+                encadre5.addLayout(hb)
+
+            hb = QHBoxLayout()
+            if self.add_combo_box(hb, 'alignement_vertical', 'Alignement vertical : ', va_values):
+                encadre5.addLayout(hb)
+
             #  FOND
             #  ====
 
@@ -290,6 +304,7 @@ class ProprietesAffichage(QWidget):
         self.add_groupbox(encadre, u"Mode d'affichage")
         self.add_groupbox(encadre1, u"Etiquette")
         self.add_groupbox(encadre2, u"Styles")
+        self.add_groupbox(encadre5, u"Alignement du texte")
         self.add_groupbox(encadre3, u"Fond et encadrement")
         self.add_groupbox(encadre4, u"Graduations")
         self.sizer.addLayout(boutons)
@@ -468,8 +483,8 @@ class ProprietesAffichage(QWidget):
                     if mode is not None or label is not None:
                         if mode is None:
                             # Conserver le mode formule, sinon basculer en mode TEXTE.
-                            mode = (FORMULE if objet.mode_affichage == FORMULE else TEXTE)
-                        self.canvas.executer(u"%s.label(%s, %s)" %(objet.nom, repr(label), mode))
+                            mode = ('formule' if objet.mode_affichage == 'formule' else 'texte')
+                        self.canvas.executer(u"%s.label(%s, %s)" %(objet.nom, repr(label), repr(mode)))
                         self.radios[mode].setChecked(True)
                         # Le texte a pu changer (ajout automatique des accolades en mode formule)
                         self.etiquette.setText(objet.legende)
