@@ -34,7 +34,7 @@ from .angles import Angle_vectoriel
 from .labels import Label_cercle, Label_arc_cercle
 from .lignes import Segment
 from .objet import Objet, Objet_avec_equation, Ref, Argument, issympy, contexte, \
-                   pi_, FILL_STYLES, TYPES_REELS, G
+                   FILL_STYLES, TYPES_REELS, G
 from .points import Point, Milieu, Centre, Point_generique, Point_equidistant, Glisseur_cercle
 from .routines import nice_display, angle_vectoriel, distance, formatage, trigshift, \
                       carre_distance_point_ellipse, vect
@@ -83,7 +83,7 @@ class Cercle_Arc_generique(Objet_avec_equation):
 
     def _distance_inf(self, x, y, d): # à surclasser pour les arcs
         x0, y0 = self._pixel(self.__centre)
-        rx, ry = self.canvas.dcoo2pix(self.rayon, self.rayon)
+        rx, ry = self.feuille.dcoo2pix(self.rayon, self.rayon)
         rx = abs(rx) ; ry = abs(ry)
         if x0 - rx - d < x < x0 + rx + d and y0 - ry - d < y < y0 + ry + d:
             return carre_distance_point_ellipse((x0, y0), rx, ry, (x, y), epsilon = .000001) < d**2
@@ -150,7 +150,8 @@ class Arc_generique(Cercle_Arc_generique):
         # On travaille avec les coordonnées de la feuille
         a, b = self._intervalle()
         z0 = self.__centre.z
-        xM, yM = self.canvas.pix2coo(x, y)
+        feuille = self.feuille
+        xM, yM = feuille.pix2coo(x, y)
         zM = xM + 1j*yM
         if abs(zM - z0) > 10*contexte['tolerance']:
             phi = phase(zM - z0)
@@ -162,8 +163,8 @@ class Arc_generique(Cercle_Arc_generique):
                 zA = z0 + rect(self.rayon, a)
                 zB = z0 + rect(self.rayon, b)
                 # On travaille maintenant avec les coordonnées en pixel
-                _xA, _yA = self.canvas.coo2pix(zA.real, zA.imag)
-                _xB, _yB = self.canvas.coo2pix(zB.real, zB.imag)
+                _xA, _yA = feuille.coo2pix(zA.real, zA.imag)
+                _xB, _yB = feuille.coo2pix(zB.real, zB.imag)
                 return min((_xA - x)**2 + (_yA - y)**2, (_xB - x)**2 + (_yB - y)**2) < d**2
         return Cercle_Arc_generique._distance_inf(self, x, y, d)
 
@@ -287,14 +288,15 @@ class Arc_generique(Cercle_Arc_generique):
         O = self.__centre
         a, b = self._intervalle()
         vec = vect(O, M)
-        if hypot(*vec) < contexte['tolerance']: # M et O sont (quasi) confondus
-            return self.rayon < contexte['tolerance'] # alors M appartient (quasiment) à l'arc ssi l'arc est de rayon (quasi) nul
+        eps = contexte['tolerance']
+        if hypot(*vec) < eps: # M et O sont (quasi) confondus
+            return self.rayon < eps # alors M appartient (quasiment) à l'arc ssi l'arc est de rayon (quasi) nul
         else:
             c = angle_vectoriel(G.vecteur_unite, vec)
             if c < a:
                 c += 2*pi
     #        print "Test tolerance arc cercle",  abs(distance(O, M) - self.rayon),  a < c < b
-            return abs(distance(O, M) - self.rayon) < contexte['tolerance'] and a - contexte['tolerance'] < c < b + contexte['tolerance']
+            return abs(distance(O, M) - self.rayon) < eps and a - eps < c < b + eps
 
 
 
@@ -526,8 +528,11 @@ class Cercle_generique(Cercle_Arc_generique):
 
 
     def _longueur(self):
-        rayon = self.rayon
-        return 2*rayon*pi_()
+        r = self.rayon
+        if contexte['exact'] and issympy(r):
+            return 2*r*PI
+        else:
+            return 2*r*pi
 
     perimetre = property(_longueur)
 
@@ -776,12 +781,11 @@ class Disque(Cercle_generique):
         x, y = self._Cercle_generique__centre.coordonnees
         r = self.rayon
         t = fullrange(0, 2*pi , self.canvas.pas())
-        fill.xy = zip(x + r*ncos(t), y + r*nsin(t))
-        fill._alpha = self.style("alpha")
-        fill._color = self.style("couleur")
-        fill._linestyle = FILL_STYLES.get(self.style("style"), "solid")
-        fill._linewidth = self.style("epaisseur")
-        fill.zorder = self.style("niveau")
+        fill.set(xy = zip(x + r*ncos(t), y + r*nsin(t)),
+                alpha = self.style("alpha"), color = self.style("couleur"),
+                linestyle = FILL_STYLES.get(self.style("style"), "solid"),
+                linewidth = self.style("epaisseur"),
+                zorder = self.style("niveau"))
 
 
     @property
@@ -789,7 +793,7 @@ class Disque(Cercle_generique):
         return self.__cercle.rayon
 
     def _distance_inf(self, x, y, d):
-        x, y = self.canvas.pix2coo(x, y)
+        x, y = self.feuille.pix2coo(x, y)
         return distance(self._Cercle_generique__centre, (x, y)) <= self.rayon
 
     def _contains(self, M):
@@ -797,7 +801,11 @@ class Disque(Cercle_generique):
 
     @property
     def aire(self):
-        return self.rayon**2*pi_()
+        r = self.rayon
+        if contexte['exact'] and issympy(r):
+            return r**2*PI
+        else:
+            return r**2*pi
 
     @property
     def info(self):
