@@ -149,16 +149,6 @@ afficher_boutons = True  # Possibilité de ne pas afficher les boutons, pour obl
 zoom_texte = 1
 zoom_ligne = 1
 
-#constantes
-RIEN = 0
-NOM = 1
-TEXTE = 2
-FORMULE = 3
-MATH = 4
-DEBUT = 0
-MILIEU = 0.5
-FIN = 1
-#TODO: supprimer cette section une fois qu'une partie de param sera directement intégrée à geolib.
 
 # Styles liés à la catégorie:
 styles_de_lignes = ['-', '--', '-.', ':', 'None']
@@ -259,6 +249,7 @@ courbes = {"couleur": "b",
     "extremites": True,
     "extremites_cachees": (),
     "sous-categorie": "courbes",
+    "taille_extremites": 4,
     }
 vecteurs = {
     "couleur": "g",
@@ -270,7 +261,7 @@ vecteurs = {
     "categorie": "lignes",
     "sous-categorie": "vecteurs",
     "angle": 60,
-    "position": FIN,
+    "position": 1, # FIN
     "double_fleche": False,
     }
 axes = {
@@ -321,7 +312,7 @@ arcs_orientes = {
     "categorie": "lignes",
     "sous-categorie": "arcs",
     "angle": 60,
-    "position": FIN,
+    "position": 1, # FIN
     "double_fleche": False,
     }
 polygones = {
@@ -374,7 +365,7 @@ textes = {
     "famille": familles_de_textes[1],
     "visible": True,
     "angle": 0,
-    "mode": TEXTE,
+    "mode": 'texte',
     "fixe": False,
     "categorie": "textes",
     "sous-categorie": "textes ordinaires",
@@ -389,10 +380,10 @@ textes = {
     "epaisseur_cadre": 1,
     'couleur_cadre': 'k',
     "style_cadre": styles_de_lignes[0],
-    "formatage": RIEN,
+    "formatage": 'rien',
     }
 champs = {
-    "formatage": MATH,
+    "formatage": 'math',
     "fixe": True,
     "sous-categorie": "champs de texte",
     }
@@ -404,7 +395,7 @@ boutons = {
     "style": "italic",
     "visible": True,
     "angle": 0,
-    "mode": TEXTE,
+    "mode": 'texte',
     "fixe": True,
     "categorie": "widgets",
     "sous-categorie": "boutons",
@@ -422,7 +413,7 @@ labels = {
     "famille": familles_de_textes[1],
     "visible": True,
     "angle": 0,
-    "mode": RIEN,
+    "mode": 'rien',
     "fixe": False,
     "categorie": "textes",
     "sous-categorie": u"étiquettes",
@@ -458,8 +449,6 @@ angles = {
 # le parametre "categorie" indique quelle liste de styles est à appliquer.
 # par défaut, on applique souvent 'styles_de_lignes'.
 
-del NOM, FORMULE, TEXTE, RIEN, DEBUT, MILIEU, FIN
-
 # Options de style pour les objets geometriques :
 #   couleur:      str
 #   epaisseur:    float
@@ -564,7 +553,10 @@ zoom_texte_out = 0.95
 zoom_ligne_in = 1.07
 zoom_ligne_out = 0.93
 
-dpi_ecran = 80
+dpi_ecran = 100
+# Taille de l'image en pixels par défaut. Sert lorsque Géophar est utilisé
+# en mode texte, ie. sans GUI, pour simuler un écran.
+dimensions_en_pixels = (800, 600)
 # Tableau récapitulatif des résolutions les plus courantes :
 # http://forum.notebookreview.com/notebook-dummy-guide-articles/124093-guide-screen-sizes-dots-per-inch-dpi.html
 
