@@ -5,6 +5,6 @@ NOMPROG = u"Géophar"
 NOMPROG2 = 'Geophar' # sans accent
 
 # Numéro de version (et date de sa sortie)
-version = '14.07'
-date_version = (2014, 7, 10)
-git = 'v14.05-15-g2fb0355'
\ No newline at end of file
+version = '14.08.1'
+date_version = (2014, 8, 13)
+git = 'v14.08-1-g8379811'
\ No newline at end of file
